@@ -373,7 +373,7 @@ xb_builder_func (void)
 
 	/* check size */
 	bytes = xb_silo_get_bytes (silo);
-	g_assert_cmpint (g_bytes_get_size (bytes), ==, 553);
+	g_assert_cmpint (g_bytes_get_size (bytes), ==, 605);
 }
 
 static void
@@ -403,6 +403,8 @@ xb_builder_custom_mime_func (void)
 {
 	gboolean ret;
 	g_autofree gchar *xml = NULL;
+	g_autofree gchar *tmp_desktop = g_build_filename (g_get_tmp_dir (), "temp.desktop", NULL);
+	g_autofree gchar *tmp_xmlb = g_build_filename (g_get_tmp_dir (), "temp.xmlb", NULL);
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GFile) file_desktop = NULL;
 	g_autoptr(GFile) file = NULL;
@@ -415,17 +417,17 @@ xb_builder_custom_mime_func (void)
 				       xb_builder_custom_mime_cb, NULL, NULL);
 
 	/* import a source file */
-	ret = g_file_set_contents ("/tmp/temp.desktop", "[Desktop Entry]", -1, &error);
+	ret = g_file_set_contents (tmp_desktop, "[Desktop Entry]", -1, &error);
 	g_assert_no_error (error);
 	g_assert_true (ret);
-	file_desktop = g_file_new_for_path ("/tmp/temp.desktop");
+	file_desktop = g_file_new_for_path (tmp_desktop);
 	ret = xb_builder_source_load_file (source, file_desktop,
 					   XB_BUILDER_SOURCE_FLAG_WATCH_FILE,
 					   NULL, &error);
 	g_assert_no_error (error);
 	g_assert_true (ret);
 	xb_builder_import_source (builder, source);
-	file = g_file_new_for_path ("/tmp/temp.xmlb");
+	file = g_file_new_for_path (tmp_xmlb);
 	silo = xb_builder_ensure (builder, file,
 				  XB_BUILDER_COMPILE_FLAG_WATCH_BLOB,
 				  NULL, &error);
@@ -449,6 +451,7 @@ xb_builder_chained_adapters_func (void)
 	gboolean ret;
 	g_autofree gchar *xml = NULL;
 	g_autofree gchar *path = NULL;
+	g_autofree gchar *tmp_xmlb = g_build_filename (g_get_tmp_dir (), "temp.xmlb", NULL);
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GFile) file_src = NULL;
 	g_autoptr(GFile) file = NULL;
@@ -469,7 +472,7 @@ xb_builder_chained_adapters_func (void)
 	g_assert_no_error (error);
 	g_assert_true (ret);
 	xb_builder_import_source (builder, source);
-	file = g_file_new_for_path ("/tmp/temp.xmlb");
+	file = g_file_new_for_path (tmp_xmlb);
 	silo = xb_builder_ensure (builder, file,
 				  XB_BUILDER_COMPILE_FLAG_NONE,
 				  NULL, &error);
@@ -496,21 +499,29 @@ xb_builder_ensure_watch_source_func (void)
 	g_autoptr(XbBuilder) builder = xb_builder_new ();
 	g_autoptr(XbBuilderSource) source = xb_builder_source_new ();
 	g_autoptr(XbSilo) silo = NULL;
+	g_autofree gchar *tmp_xml = g_build_filename (g_get_tmp_dir (), "temp.xml", NULL);
+	g_autofree gchar *tmp_xmlb = g_build_filename (g_get_tmp_dir (), "temp.xmlb", NULL);
+
+#ifdef _WIN32
+	/* no inotify */
+	g_test_skip ("inotify does not work on mingw");
+	return;
+#endif
 
 	/* import a source file */
-	ret = g_file_set_contents ("/tmp/temp.xml",
+	ret = g_file_set_contents (tmp_xml,
 				   "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
 				   "<id>gimp</id>", -1, &error);
 	g_assert_no_error (error);
 	g_assert_true (ret);
-	file_xml = g_file_new_for_path ("/tmp/temp.xml");
+	file_xml = g_file_new_for_path (tmp_xml);
 	ret = xb_builder_source_load_file (source, file_xml,
 					   XB_BUILDER_SOURCE_FLAG_WATCH_FILE,
 					   NULL, &error);
 	g_assert_no_error (error);
 	g_assert_true (ret);
 	xb_builder_import_source (builder, source);
-	file = g_file_new_for_path ("/tmp/temp.xmlb");
+	file = g_file_new_for_path (tmp_xmlb);
 	g_file_delete (file, NULL, NULL);
 	silo = xb_builder_ensure (builder, file,
 				  XB_BUILDER_COMPILE_FLAG_WATCH_BLOB,
@@ -523,7 +534,7 @@ xb_builder_ensure_watch_source_func (void)
 			  &invalidate_cnt);
 
 	/* change source file */
-	ret = g_file_set_contents ("/tmp/temp.xml",
+	ret = g_file_set_contents (tmp_xml,
 				   "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
 				   "<id>inkscape</id>", -1, &error);
 	g_assert_no_error (error);
@@ -539,6 +550,7 @@ xb_builder_ensure_func (void)
 {
 	gboolean ret;
 	guint invalidate_cnt = 0;
+	g_autofree gchar *tmp_xmlb = g_build_filename (g_get_tmp_dir (), "temp.xmlb", NULL);
 	g_autoptr(GBytes) bytes1 = NULL;
 	g_autoptr(GBytes) bytes2 = NULL;
 	g_autoptr(GBytes) bytes3 = NULL;
@@ -567,6 +579,12 @@ xb_builder_ensure_func (void)
 		"  </component>\n"
 		"</components>\n";
 
+#ifdef _WIN32
+	/* no inotify */
+	g_test_skip ("inotify does not work on mingw");
+	return;
+#endif
+
 	/* import some XML */
 	xb_builder_set_profile_flags (builder, XB_SILO_PROFILE_FLAG_DEBUG);
 	ret = xb_test_import_xml (builder, xml, &error);
@@ -574,7 +592,7 @@ xb_builder_ensure_func (void)
 	g_assert_true (ret);
 
 	/* create file if it does not exist */
-	file = g_file_new_for_path ("/tmp/temp.xmlb");
+	file = g_file_new_for_path (tmp_xmlb);
 	g_file_delete (file, NULL, NULL);
 	silo = xb_builder_ensure (builder, file,
 				  XB_BUILDER_COMPILE_FLAG_WATCH_BLOB,
@@ -1924,9 +1942,9 @@ xb_builder_node_source_text_func (void)
 static void
 xb_builder_node_info_func (void)
 {
-	const gchar *fn = "/tmp/xb-self-test.xml";
 	gboolean ret;
 	g_autofree gchar *xml = NULL;
+	g_autofree gchar *tmp_xml = g_build_filename (g_get_tmp_dir (), "temp.xml", NULL);
 	g_autoptr(GError) error = NULL;
 	g_autoptr(XbBuilderSource) import1 = xb_builder_source_new ();
 	g_autoptr(XbBuilderSource) import2 = xb_builder_source_new ();
@@ -1938,7 +1956,7 @@ xb_builder_node_info_func (void)
 	g_autoptr(GFile) file = NULL;
 
 	/* create a simple document with some info */
-	ret = g_file_set_contents (fn,
+	ret = g_file_set_contents (tmp_xml,
 				   "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
 				   "<component><id type=\"desktop\">dave</id></component>",
 				   -1, &error);
@@ -1950,7 +1968,7 @@ xb_builder_node_info_func (void)
 	xb_builder_node_insert_text (info2, "scope", "system", NULL);
 
 	/* import the doc */
-	file = g_file_new_for_path (fn);
+	file = g_file_new_for_path (tmp_xml);
 	ret = xb_builder_source_load_file (import1, file, XB_BUILDER_SOURCE_FLAG_NONE, NULL, &error);
 	g_assert_no_error (error);
 	g_assert_true (ret);
@@ -2059,13 +2077,111 @@ xb_threading_func (void)
 	g_thread_pool_free (pool, FALSE, TRUE);
 }
 
+typedef struct {
+	guint		 cnt;
+	GString		*str;
+} XbMarkupHelper;
+
+static gboolean
+xb_markup_head_cb (XbNode *n, gpointer user_data)
+{
+	XbMarkupHelper *helper = (XbMarkupHelper *) user_data;
+	helper->cnt++;
+
+	if (xb_node_get_text (n) == NULL)
+		return FALSE;
+
+	/* start */
+	if (g_strcmp0 (xb_node_get_element (n), "em") == 0) {
+		g_string_append (helper->str, "*");
+	} else if (g_strcmp0 (xb_node_get_element (n), "strong") == 0) {
+		g_string_append (helper->str, "**");
+	} else if (g_strcmp0 (xb_node_get_element (n), "code") == 0) {
+		g_string_append (helper->str, "`");
+	}
+
+	/* text */
+	if (xb_node_get_text (n) != NULL)
+		g_string_append (helper->str, xb_node_get_text (n));
+
+	return FALSE;
+}
+
+static gboolean
+xb_markup_tail_cb (XbNode *n, gpointer user_data)
+{
+	XbMarkupHelper *helper = (XbMarkupHelper *) user_data;
+	helper->cnt++;
+
+	/* end */
+	if (g_strcmp0 (xb_node_get_element (n), "em") == 0) {
+		g_string_append (helper->str, "*");
+	} else if (g_strcmp0 (xb_node_get_element (n), "strong") == 0) {
+		g_string_append (helper->str, "**");
+	} else if (g_strcmp0 (xb_node_get_element (n), "code") == 0) {
+		g_string_append (helper->str, "`");
+	} else if (g_strcmp0 (xb_node_get_element (n), "p") == 0) {
+		g_string_append (helper->str, "\n\n");
+	}
+
+	/* tail */
+	if (xb_node_get_tail (n) != NULL)
+		g_string_append (helper->str, xb_node_get_tail (n));
+
+	return FALSE;
+}
+
+static void
+xb_markup_func (void)
+{
+	gboolean ret;
+	g_autofree gchar *new = NULL;
+	g_autofree gchar *tmp = NULL;
+	g_autoptr(GError) error = NULL;
+	g_autoptr(XbNode) n = NULL;
+	g_autoptr(XbSilo) silo = NULL;
+	XbMarkupHelper helper = {
+		.cnt = 0,
+		.str = g_string_new (NULL),
+	};
+	const gchar *xml = "<description>"
+			   "<p><code>Title</code>:</p>"
+			   "<p>There is a <em>slight</em> risk of <strong>death</strong> here<a>!</a></p>"
+			   "</description>";
+
+	/* import from XML */
+	silo = xb_silo_new_from_xml (xml, &error);
+	g_assert_no_error (error);
+	g_assert_nonnull (silo);
+
+	/* ensure we can round-trip */
+	tmp = xb_silo_to_string (silo, &error);
+	g_assert_no_error (error);
+	g_assert_nonnull (silo);
+	g_debug ("\n%s", tmp);
+	n = xb_silo_get_root (silo);
+	g_assert_nonnull (n);
+	new = xb_node_export (n, XB_NODE_EXPORT_FLAG_NONE, &error);
+	g_assert_no_error (error);
+	g_assert_nonnull (new);
+	g_assert_cmpstr (xml, ==, new);
+
+	/* ensure we can convert this to another format */
+	ret = xb_node_transmogrify (n, xb_markup_head_cb, xb_markup_tail_cb, &helper);
+	g_assert_true (ret);
+	g_assert_cmpstr (helper.str->str, ==,
+			 "`Title`:\n\nThere is a *slight* risk of **death** here!\n\n");
+	g_assert_cmpint (helper.cnt, ==, 14);
+	g_string_free (helper.str, TRUE);
+}
+
 static void
 xb_speed_func (void)
 {
 	XbNode *n;
-	const gchar *fn = "/tmp/test.xmlb";
 	gboolean ret;
 	guint n_components = 5000;
+	g_autofree gchar *tmp_xmlb = g_build_filename (g_get_tmp_dir (), "test.xmlb", NULL);
 	g_autofree gchar *xpath1 = NULL;
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GFile) file = NULL;
@@ -2113,7 +2229,7 @@ xb_speed_func (void)
 	silo = xb_silo_new_from_xml (xml->str, &error);
 	g_assert_no_error (error);
 	g_assert_nonnull (silo);
-	file = g_file_new_for_path (fn);
+	file = g_file_new_for_path (tmp_xmlb);
 	ret = xb_silo_save_to_file (silo, file, NULL, &error);
 	g_assert_no_error (error);
 	g_assert_true (ret);
@@ -2249,6 +2365,7 @@ main (int argc, char **argv)
 	g_test_add_func ("/libxmlb/builder-node{info}", xb_builder_node_info_func);
 	g_test_add_func ("/libxmlb/builder-node{literal-text}", xb_builder_node_literal_text_func);
 	g_test_add_func ("/libxmlb/builder-node{source-text}", xb_builder_node_source_text_func);
+	g_test_add_func ("/libxmlb/markup", xb_markup_func);
 	g_test_add_func ("/libxmlb/xpath", xb_xpath_func);
 	g_test_add_func ("/libxmlb/xpath-query", xb_xpath_query_func);
 	g_test_add_func ("/libxmlb/xpath{helpers}", xb_xpath_helpers_func);
