@@ -184,7 +184,7 @@ xb_silo_query_part (XbSilo *self,
 /**
  * xb_silo_query_with_root: (skip)
  * @self: a #XbSilo
- * @n: a #XbNode
+ * @n: (allow-none): a #XbNode
  * @xpath: an XPath, e.g. `/components/component[@type=desktop]/id[abe.desktop]`
  * @limit: maximum number of results to return, or 0 for "all"
  * @error: the #GError, or %NULL
@@ -290,11 +290,10 @@ xb_silo_query_with_root (XbSilo *self, XbNode *n, const gchar *xpath, guint limi
 }
 
 /**
- * xb_silo_query_full: (skip)
+ * xb_silo_query_with_root_full: (skip)
  * @self: a #XbSilo
- * @n: a #XbNode
+ * @n: (allow-none): a #XbNode
  * @query: an #XbQuery
- * @limit: maximum number of results to return, or 0 for "all"
  * @error: the #GError, or %NULL
  *
  * Searches the silo using an XPath query, returning up to @limit results.
@@ -309,7 +308,7 @@ xb_silo_query_with_root (XbSilo *self, XbNode *n, const gchar *xpath, guint limi
  * Since: 0.1.4
  **/
 GPtrArray *
-xb_silo_query_full (XbSilo *self, XbNode *n, XbQuery *query, GError **error)
+xb_silo_query_with_root_full (XbSilo *self, XbNode *n, XbQuery *query, GError **error)
 {
 	XbSiloNode *sn = NULL;
 	g_autoptr(GHashTable) results_hash = g_hash_table_new (g_direct_hash, g_direct_equal);
@@ -320,10 +319,6 @@ xb_silo_query_full (XbSilo *self, XbNode *n, XbQuery *query, GError **error)
 		.position = 0,
 	};
 
-	g_return_val_if_fail (XB_IS_SILO (self), NULL);
-	g_return_val_if_fail (XB_IS_QUERY (query), NULL);
-	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
-
 	/* empty silo */
 	if (xb_silo_is_empty (self)) {
 		g_set_error_literal (error,
@@ -344,26 +339,81 @@ xb_silo_query_full (XbSilo *self, XbNode *n, XbQuery *query, GError **error)
 
 	/* profile */
 	if (xb_silo_get_profile_flags (self) & XB_SILO_PROFILE_FLAG_XPATH) {
+		g_autofree gchar *tmp = xb_query_to_string (query);
 		xb_silo_add_profile (self, timer,
 				     "query on %s with `%s` limit=%u -> %u results",
 				     n != NULL ? xb_node_get_element (n) : "/",
-				     xb_query_get_xpath (query),
+				     tmp,
 				     xb_query_get_limit (query),
 				     results->len);
 	}
 
 	/* nothing found */
 	if (results->len == 0) {
+		g_autofree gchar *tmp = xb_query_to_string (query);
 		g_set_error (error,
 			     G_IO_ERROR,
 			     G_IO_ERROR_NOT_FOUND,
 			     "no results for XPath query '%s'",
-			     xb_query_get_xpath (query));
+			     tmp);
 		return NULL;
 	}
 	return g_steal_pointer (&results);
 }
 
+/**
+ * xb_silo_query_full:
+ * @self: a #XbSilo
+ * @query: an #XbQuery
+ * @error: the #GError, or %NULL
+ *
+ * Searches the silo using an XPath query.
+ *
+ * It is safe to call this function from a different thread to the one that
+ * created the #XbSilo.
+ *
+ * Please note: Only a subset of XPath is supported.
+ *
+ * Returns: (transfer container) (element-type XbNode): results, or %NULL if unfound
+ *
+ * Since: 0.1.13
+ **/
+GPtrArray *
+xb_silo_query_full (XbSilo *self, XbQuery *query, GError **error)
+{
+	g_return_val_if_fail (XB_IS_SILO (self), NULL);
+	g_return_val_if_fail (XB_IS_QUERY (query), NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+	return xb_silo_query_with_root_full (self, NULL, query, error);
+}
+
+/**
+ * xb_silo_query_first_full:
+ * @self: a #XbSilo
+ * @query: an #XbQuery
+ * @error: the #GError, or %NULL
+ *
+ * Searches the silo using an XPath query, returning up to one result.
+ *
+ * It is safe to call this function from a different thread to the one that
+ * created the #XbSilo.
+ *
+ * Please note: Only a tiny subset of XPath 1.0 is supported.
+ *
+ * Returns: (transfer none): a #XbNode, or %NULL if unfound
+ *
+ * Since: 0.1.13
+ **/
+XbNode *
+xb_silo_query_first_full (XbSilo *self, XbQuery *query, GError **error)
+{
+	g_autoptr(GPtrArray) results = NULL;
+	results = xb_silo_query_full (self, query, error);
+	if (results == NULL)
+		return NULL;
+	return g_object_ref (g_ptr_array_index (results, 0));
+}
+
 /**
  * xb_silo_query:
  * @self: a #XbSilo
